# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#  Copyright 2013 Canonical Ltd.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation; version 3.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Chewie-client autopilot tests."""

import os.path

from autopilot.input import Mouse, Touch, Pointer
from autopilot.platform import model
from autopilot.testcase import AutopilotTestCase

from chewie_client.emulators.main_window import MainWindow


class ChewieClientTestCase(AutopilotTestCase):
    """A common test case class that provides several useful methods
       for the chewie-client tests."""

    if model() == 'Desktop':
        scenarios = [
        ('with mouse', dict(input_device_class=Mouse)),
        ]
    else:
        scenarios = [
        ('with touch', dict(input_device_class=Touch)),
        ]

    def setUp(self):
        self.pointing_device = Pointer(self.input_device_class.create())
        super(ChewieClientTestCase, self).setUp()
        # Lets assume we are installed system wide if this file is in /usr
        if os.path.realpath(__file__).startswith("/usr/") or os.path.realpath(__file__).startswith("/opt/"):
            self.launch_test_installed()
        else:
            self.launch_test_local()

    def launch_test_local(self):
        self.app = self.launch_test_application(
            "../../client/chewie-client",
            "--plugins-dir=../../plugins",
            "--include-dir=../../chewieui"
            )

    def launch_test_installed(self):
        if model() == 'Desktop':
            self.app = self.launch_test_application(
                "chewie-client"
                )
        else:
            self.app = self.launch_test_application(
                "chewie-client",
                "--desktop_file_hint=/usr/share/applications/chewie-client.desktop",
                app_type='qt')

    @property
    def main_window(self):
        return MainWindow(self.app)
